@@ -1,20 +1,9 @@
 #!/usr/bin/env python
-# Copyright The GeoML Team
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+from inspect import getdoc, getmembers, isfunction
+
 import matplotlib.pyplot as plt
 import torch
-from inspect import getmembers, isfunction, getdoc
+
 
 # Function to convert a list of arguments containing torch tensors, into
 # a corresponding list of arguments containing numpy arrays
